@@ -483,7 +483,7 @@ class Ui_MainWindow(object):
         self.genVar_button.setText(_translate("MainWindow", "Generate Variables"))
         self.genVar_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tabs.setTabText(self.tabs.indexOf(self.genVar), _translate("MainWindow", "Generate Variable"))
-        self.info_label.setText(_translate("MainWindow", "Current version v2.0.4 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v2.0.6 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -573,8 +573,14 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
             self.data_explr_df_dict = {rat: pd.read_excel(file, sheet_name = str(rat)) for rat in rat_ids}
         except:
             QMessageBox.about(self, 'Error', 'Invalid IDs or filepath')
-        colname = list(self.data_explr_df_dict[rat_ids[0]].columns)
         
+        try:
+            colname = list(self.data_explr_df_dict[str(rat_ids[0])].columns)
+        except:
+            colname = list(self.data_explr_df_dict[int(rat_ids[0])].columns)
+        else:
+            QMessageBox.about(self, 'Error', 'Invalid IDs or filepath')
+
         self.events_combo.clear()
         self.events_combo.addItems(colname)
         self.events_combo.update()
